/* Routines for sending stuff to the network.
 *
 * Services is copyright (c) 1996-1997 Andy Church.
 *     E-mail: <achurch@dragonfire.net>   IRC: Alcan@EsperNet
 * This program is free but copyrighted software; see the file COPYING for
 * details.
 */

#include "services.h"

/*************************************************************************/

/* Send a command to the server. */
void send_cmd(const char *source, const char *fmt,...)
{
    va_list args;
    char buf[2048];	/* better not get this big... */

    va_start(args, fmt);
    vsprintf(buf, fmt, args);
    if (source)
	sockprintf(servsock, ":%s %s\r\n", source, buf);
    else
	sockprintf(servsock, "%s\r\n", buf);
}

/*************************************************************************/

/* Send out a GLOBOPS.  This is called wallops() because it historically
 * sent a WALLOPS. */
void wallops(const char *fmt,...)
{
    va_list args;
    char buf[2048];

    va_start(args, fmt);
    vsprintf(buf, fmt, args);
    sockprintf(servsock, ":%s GLOBOPS :%s\r\n", SERVER_NAME, buf);
}

/*************************************************************************/

/* Send a NOTICE from the given source to the given nick. */
void notice(const char *source, const char *dest, const char *fmt,...)
{
    va_list args;
    char buf[2048];

    va_start(args, fmt);
    vsprintf(buf, fmt, args);
    sockprintf(servsock, ":%s NOTICE %s :%s\r\n", source, dest, buf);
}

/* Send a NULL-terminated array of text as NOTICEs. */
void notice_list(const char *source, const char *dest, const char **text)
{
    while (*text) {
    	/* Have to kludge around an ircII bug here: if a notice includes
    	 * no text, it is ignored, so we replace blank lines by lines
    	 * with a single space.
    	 */
    	if (**text)
	    sockprintf(servsock, ":%s NOTICE %s :%s\r\n", source, dest, *text);
	else
	    sockprintf(servsock, ":%s NOTICE %s : \r\n", source, dest);
	text++;
    }
}

/*************************************************************************/

/* Send a PRIVMSG from the given source to the given nick. */
void privmsg(const char *source, const char *dest, const char *fmt,...)
{
    va_list args;
    char buf[2048];

    va_start(args, fmt);
    vsprintf(buf, fmt, args);
    sockprintf(servsock, ":%s PRIVMSG %s :%s\r\n", source, dest, buf);
}
